<?php

namespace Bixo\Salary\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Salary\Models\Adjustments;

class AdjustmentsPolicy
{

    /**
     * Determine if the given user can view the adjustments.
     *
     * @param UserPolicy $user
     * @param Adjustments $adjustments
     *
     * @return bool
     */
    public function view(UserPolicy $user, Adjustments $adjustments)
    {
        if ($user->canDo('salary.adjustments.view') && $user->isAdmin()) {
            return true;
        }

        return $adjustments->user_id == user_id() && $adjustments->user_type == user_type();
    }

    /**
     * Determine if the given user can create a adjustments.
     *
     * @param UserPolicy $user
     * @param Adjustments $adjustments
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('salary.adjustments.create');
    }

    /**
     * Determine if the given user can update the given adjustments.
     *
     * @param UserPolicy $user
     * @param Adjustments $adjustments
     *
     * @return bool
     */
    public function update(UserPolicy $user, Adjustments $adjustments)
    {
        if ($user->canDo('salary.adjustments.edit') && $user->isAdmin()) {
            return true;
        }

        return $adjustments->user_id == user_id() && $adjustments->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given adjustments.
     *
     * @param UserPolicy $user
     * @param Adjustments $adjustments
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Adjustments $adjustments)
    {
        return $adjustments->user_id == user_id() && $adjustments->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given adjustments.
     *
     * @param UserPolicy $user
     * @param Adjustments $adjustments
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Adjustments $adjustments)
    {
        if ($user->canDo('salary.adjustments.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given adjustments.
     *
     * @param UserPolicy $user
     * @param Adjustments $adjustments
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Adjustments $adjustments)
    {
        if ($user->canDo('salary.adjustments.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
