<?php

namespace Bixo\Salary\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Salary\Models\Payrolls;

class PayrollsPolicy
{

    /**
     * Determine if the given user can view the payrolls.
     *
     * @param UserPolicy $user
     * @param Payrolls $payrolls
     *
     * @return bool
     */
    public function view(UserPolicy $user, Payrolls $payrolls)
    {
        if ($user->canDo('salary.payrolls.view') && $user->isAdmin()) {
            return true;
        }

        return $payrolls->user_id == user_id() && $payrolls->user_type == user_type();
    }

    /**
     * Determine if the given user can create a payrolls.
     *
     * @param UserPolicy $user
     * @param Payrolls $payrolls
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('salary.payrolls.create');
    }

    /**
     * Determine if the given user can update the given payrolls.
     *
     * @param UserPolicy $user
     * @param Payrolls $payrolls
     *
     * @return bool
     */
    public function update(UserPolicy $user, Payrolls $payrolls)
    {
        if ($user->canDo('salary.payrolls.edit') && $user->isAdmin()) {
            return true;
        }

        return $payrolls->user_id == user_id() && $payrolls->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given payrolls.
     *
     * @param UserPolicy $user
     * @param Payrolls $payrolls
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Payrolls $payrolls)
    {
        return $payrolls->user_id == user_id() && $payrolls->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given payrolls.
     *
     * @param UserPolicy $user
     * @param Payrolls $payrolls
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Payrolls $payrolls)
    {
        if ($user->canDo('salary.payrolls.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given payrolls.
     *
     * @param UserPolicy $user
     * @param Payrolls $payrolls
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Payrolls $payrolls)
    {
        if ($user->canDo('salary.payrolls.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
