<?php

namespace Bixo\Salary\Providers;

use Illuminate\Support\ServiceProvider;

class SalaryServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'salary');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'salary');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerSalary();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerSalary()
    {
        $this->app->bind('salary', function($app) {
            return new Salary($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Salary', 'Lavalite\Salary\Facades\Salary');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('bixo.salary', function ($app) {
            return $this->app->make('Bixo\Salary\Salary');
        });

        // Bind Adjustments to repository
        $this->app->bind(
            'Bixo\Salary\Interfaces\AdjustmentsRepositoryInterface',
            \Bixo\Salary\Repositories\Eloquent\AdjustmentsRepository::class
        );        // Bind Payrolls to repository
        $this->app->bind(
            'Bixo\Salary\Interfaces\PayrollsRepositoryInterface',
            \Bixo\Salary\Repositories\Eloquent\PayrollsRepository::class
        );

        $this->app->register(\Bixo\Salary\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Bixo\Salary\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and salary's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.salary'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeSalary::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.salary'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('bixo/salary.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/salary')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/salary')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
